pub struct TypeParameters { /* private fields */ }Expand description
Represents the set of generic type parameters for generating a type definition e.g. the T in
Foo<T>.
Additionally this allows generating a PhantomData type for any type params which are unused
in the type definition itself.
Implementations
Sourceimpl TypeParameters
impl TypeParameters
Sourcepub fn from_scale_info(params: &[TypeParameter<PortableForm>]) -> Self
pub fn from_scale_info(params: &[TypeParameter<PortableForm>]) -> Self
Create a new TypeParameters instance.
Sourcepub fn unused_params_phantom_data(&self) -> Option<TypePath>
pub fn unused_params_phantom_data(&self) -> Option<TypePath>
Construct a core::marker::PhantomData for the type unused type params.
Sourcepub fn params(&self) -> &[TypeParameter]
pub fn params(&self) -> &[TypeParameter]
Returns the set of type parameters.
Sourcepub fn has_unused_type_params(&self) -> bool
pub fn has_unused_type_params(&self) -> bool
Returns true if there are any unused type params